@@ -10,7 +10,7 @@ use DBI;
 use List::Util qw(first);
 
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 
 =head1 NAME
@@ -84,7 +84,7 @@ See L<Net::Google::SafeBrowsing2::Storage> for a complete list of public functio
 
 Cleanup old full hashes, and close the connection to the database.
 
-  my $storage->clode();
+  my $storage->close();
 
 
 =cut
@@ -559,6 +559,10 @@ Add table and function to store and retrieve the Message Authentication Code (MA
 
 In some environments, the module was trying to re-create exising tables. Fixed (Thank you to  Luis Alberto Perez).
 
+=item 0.3
+
+Fix typos in the documentation.
+
 =back
 
 
